@@ -9,17 +9,22 @@
 #' directives that apply to the whole package (vs. a specific function), such as
 #' global namespace tags like `@importFrom`.
 #'
-#' @seealso The [documentation chapter](http://r-pkgs.had.co.nz/man.html) of [R
-#'   Packages](http://r-pkgs.had.co.nz)
+#' @seealso The [documentation chapter](https://r-pkgs.org/man.html) of [R
+#'   Packages](https://r-pkgs.org)
 #'
 #' @export
 use_package_doc <- function() {
   check_is_package("use_package_doc()")
-  name <- project_name()
-
   use_template(
     "packagename-package.R",
-    path("R", paste0(name, "-package"), ext = "R"),
-    data = list(name = name)
+    package_doc_path()
   )
 }
+
+package_doc_path <- function() {
+  path("R", paste0(project_name(), "-package"), ext = "R")
+}
+
+has_package_doc <- function() {
+  file_exists(proj_path(package_doc_path()))
+}
